@@ -1,6 +1,4 @@
 """Support for Blinkstick lights."""
-import logging
-
 from blinkstick import blinkstick
 import voluptuous as vol
 
@@ -16,8 +14,6 @@ from homeassistant.const import CONF_NAME
 import homeassistant.helpers.config_validation as cv
 import homeassistant.util.color as color_util
 
-_LOGGER = logging.getLogger(__name__)
-
 CONF_SERIAL = "serial"
 
 DEFAULT_NAME = "Blinkstick"
@@ -54,11 +50,6 @@ class BlinkStickLight(LightEntity):
         self._hs_color = None
         self._brightness = None
 
-    @property
-    def should_poll(self):
-        """Set up polling."""
-        return True
-
     @property
     def name(self):
         """Return the name of the light."""
