@@ -1,5 +1,6 @@
 """Support for Broadlink switches."""
 from abc import ABC, abstractmethod
+from functools import partial
 import logging
 
 from broadlink.exceptions import BroadlinkException
@@ -121,6 +122,12 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     elif device.api.type == "SP2":
         switches = [BroadlinkSP2Switch(device)]
 
+    elif device.api.type in {"SP4", "SP4B"}:
+        switches = [BroadlinkSP4Switch(device)]
+
+    elif device.api.type == "BG1":
+        switches = [BroadlinkBG1Slot(device, slot) for slot in range(1, 3)]
+
     elif device.api.type == "MP1":
         switches = [BroadlinkMP1Slot(device, slot) for slot in range(1, 5)]
 
@@ -294,6 +301,27 @@ class BroadlinkSP2Switch(BroadlinkSP1Switch):
         self.async_write_ha_state()
 
 
+class BroadlinkSP4Switch(BroadlinkSP1Switch):
+    """Representation of a Broadlink SP4 switch."""
+
+    def __init__(self, device, *args, **kwargs):
+        """Initialize the switch."""
+        super().__init__(device, *args, **kwargs)
+        self._state = self._coordinator.data["pwr"]
+
+    @property
+    def assumed_state(self):
+        """Return True if unable to access real state of the switch."""
+        return False
+
+    @callback
+    def update_data(self):
+        """Update data."""
+        if self._coordinator.last_update_success:
+            self._state = self._coordinator.data["pwr"]
+        self.async_write_ha_state()
+
+
 class BroadlinkMP1Slot(BroadlinkSwitch):
     """Representation of a Broadlink MP1 slot."""
 
@@ -336,3 +364,46 @@ class BroadlinkMP1Slot(BroadlinkSwitch):
             _LOGGER.error("Failed to send packet: %s", err)
             return False
         return True
+
+
+class BroadlinkBG1Slot(BroadlinkSwitch):
+    """Representation of a Broadlink BG1 slot."""
+
+    def __init__(self, device, slot):
+        """Initialize the switch."""
+        super().__init__(device, 1, 0)
+        self._slot = slot
+        self._state = self._coordinator.data[f"pwr{slot}"]
+        self._device_class = DEVICE_CLASS_OUTLET
+
+    @property
+    def unique_id(self):
+        """Return the unique id of the slot."""
+        return f"{self._device.unique_id}-s{self._slot}"
+
+    @property
+    def name(self):
+        """Return the name of the switch."""
+        return f"{self._device.name} S{self._slot}"
+
+    @property
+    def assumed_state(self):
+        """Return True if unable to access real state of the switch."""
+        return False
+
+    @callback
+    def update_data(self):
+        """Update data."""
+        if self._coordinator.last_update_success:
+            self._state = self._coordinator.data[f"pwr{self._slot}"]
+        self.async_write_ha_state()
+
+    async def _async_send_packet(self, packet):
+        """Send a packet to the device."""
+        set_state = partial(self._device.api.set_state, **{f"pwr{self._slot}": packet})
+        try:
+            await self._device.async_request(set_state)
+        except (BroadlinkException, OSError) as err:
+            _LOGGER.error("Failed to send packet: %s", err)
+            return False
+        return True
