@@ -1,8 +1,10 @@
 """Support for Dutch Smart Meter (also known as Smartmeter or P1 port)."""
 import asyncio
 from asyncio import CancelledError
+from datetime import timedelta
 from functools import partial
 import logging
+from typing import Dict
 
 from dsmr_parser import obis_references as obis_ref
 from dsmr_parser.clients.protocol import create_dsmr_reader, create_tcp_dsmr_reader
@@ -21,16 +23,23 @@ from homeassistant.core import CoreState, callback
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.typing import HomeAssistantType
+from homeassistant.util import Throttle
 
 from .const import (
     CONF_DSMR_VERSION,
     CONF_PRECISION,
     CONF_RECONNECT_INTERVAL,
+    CONF_SERIAL_ID,
+    CONF_SERIAL_ID_GAS,
+    CONF_TIME_BETWEEN_UPDATE,
     DATA_TASK,
     DEFAULT_DSMR_VERSION,
     DEFAULT_PORT,
     DEFAULT_PRECISION,
     DEFAULT_RECONNECT_INTERVAL,
+    DEFAULT_TIME_BETWEEN_UPDATE,
+    DEVICE_NAME_ENERGY,
+    DEVICE_NAME_GAS,
     DOMAIN,
     ICON_GAS,
     ICON_POWER,
@@ -66,10 +75,8 @@ async def async_setup_entry(
     hass: HomeAssistantType, entry: ConfigEntry, async_add_entities
 ) -> None:
     """Set up the DSMR sensor."""
-    # Suppress logging
-    logging.getLogger("dsmr_parser").setLevel(logging.ERROR)
-
     config = entry.data
+    options = entry.options
 
     dsmr_version = config[CONF_DSMR_VERSION]
 
@@ -106,24 +113,45 @@ async def async_setup_entry(
     ]
 
     # Generate device entities
-    devices = [DSMREntity(name, obis, config) for name, obis in obis_mapping]
+    devices = [
+        DSMREntity(name, DEVICE_NAME_ENERGY, config[CONF_SERIAL_ID], obis, config)
+        for name, obis in obis_mapping
+    ]
 
     # Protocol version specific obis
-    if dsmr_version in ("4", "5"):
-        gas_obis = obis_ref.HOURLY_GAS_METER_READING
-    elif dsmr_version in ("5B",):
-        gas_obis = obis_ref.BELGIUM_HOURLY_GAS_METER_READING
-    else:
-        gas_obis = obis_ref.GAS_METER_READING
+    if CONF_SERIAL_ID_GAS in config:
+        if dsmr_version in ("4", "5"):
+            gas_obis = obis_ref.HOURLY_GAS_METER_READING
+        elif dsmr_version in ("5B",):
+            gas_obis = obis_ref.BELGIUM_HOURLY_GAS_METER_READING
+        else:
+            gas_obis = obis_ref.GAS_METER_READING
 
-    # Add gas meter reading and derivative for usage
-    devices += [
-        DSMREntity("Gas Consumption", gas_obis, config),
-        DerivativeDSMREntity("Hourly Gas Consumption", gas_obis, config),
-    ]
+        # Add gas meter reading and derivative for usage
+        devices += [
+            DSMREntity(
+                "Gas Consumption",
+                DEVICE_NAME_GAS,
+                config[CONF_SERIAL_ID_GAS],
+                gas_obis,
+                config,
+            ),
+            DerivativeDSMREntity(
+                "Hourly Gas Consumption",
+                DEVICE_NAME_GAS,
+                config[CONF_SERIAL_ID_GAS],
+                gas_obis,
+                config,
+            ),
+        ]
 
     async_add_entities(devices)
 
+    min_time_between_updates = timedelta(
+        seconds=options.get(CONF_TIME_BETWEEN_UPDATE, DEFAULT_TIME_BETWEEN_UPDATE)
+    )
+
+    @Throttle(min_time_between_updates)
     def update_entities_telegram(telegram):
         """Update entities with latest telegram and trigger state update."""
         # Make all device entities aware of new telegram
@@ -209,18 +237,22 @@ async def async_setup_entry(
 class DSMREntity(Entity):
     """Entity reading values from DSMR telegram."""
 
-    def __init__(self, name, obis, config):
+    def __init__(self, name, device_name, device_serial, obis, config):
         """Initialize entity."""
         self._name = name
         self._obis = obis
         self._config = config
         self.telegram = {}
 
+        self._device_name = device_name
+        self._device_serial = device_serial
+        self._unique_id = f"{device_serial}_{name}".replace(" ", "_")
+
     @callback
     def update_data(self, telegram):
         """Update data."""
         self.telegram = telegram
-        if self.hass:
+        if self.hass and self._obis in self.telegram:
             self.async_write_ha_state()
 
     def get_dsmr_object_attr(self, attribute):
@@ -273,6 +305,19 @@ class DSMREntity(Entity):
         """Return the unit of measurement of this entity, if any."""
         return self.get_dsmr_object_attr("unit")
 
+    @property
+    def unique_id(self) -> str:
+        """Return a unique ID."""
+        return self._unique_id
+
+    @property
+    def device_info(self) -> Dict[str, any]:
+        """Return the device information."""
+        return {
+            "identifiers": {(DOMAIN, self._device_serial)},
+            "name": self._device_name,
+        }
+
     @property
     def force_update(self):
         """Force update."""
