@@ -12,10 +12,10 @@ from homeassistant.components.light import (
     SUPPORT_WHITE_VALUE,
     LightEntity,
 )
-from homeassistant.core import callback
 import homeassistant.util.color as color_util
 
-from . import DATA_KNX
+from .const import DOMAIN
+from .knx_entity import KnxEntity
 
 DEFAULT_COLOR = (0.0, 0.0)
 DEFAULT_BRIGHTNESS = 255
@@ -25,18 +25,18 @@ DEFAULT_WHITE_VALUE = 255
 async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up lights for KNX platform."""
     entities = []
-    for device in hass.data[DATA_KNX].xknx.devices:
+    for device in hass.data[DOMAIN].xknx.devices:
         if isinstance(device, XknxLight):
             entities.append(KNXLight(device))
     async_add_entities(entities)
 
 
-class KNXLight(LightEntity):
+class KNXLight(KnxEntity, LightEntity):
     """Representation of a KNX light."""
 
     def __init__(self, device: XknxLight):
         """Initialize of KNX light."""
-        self.device = device
+        super().__init__(device)
 
         self._min_kelvin = device.min_kelvin
         self._max_kelvin = device.max_kelvin
@@ -47,46 +47,13 @@ class KNXLight(LightEntity):
             self._min_kelvin
         )
 
-    @callback
-    def async_register_callbacks(self):
-        """Register callbacks to update hass after device was changed."""
-
-        async def after_update_callback(device):
-            """Call after device was updated."""
-            self.async_write_ha_state()
-
-        self.device.register_device_updated_cb(after_update_callback)
-
-    async def async_added_to_hass(self):
-        """Store register state change callback."""
-        self.async_register_callbacks()
-
-    async def async_update(self):
-        """Request a state update from KNX bus."""
-        await self.device.sync()
-
-    @property
-    def name(self):
-        """Return the name of the KNX device."""
-        return self.device.name
-
-    @property
-    def available(self):
-        """Return True if entity is available."""
-        return self.hass.data[DATA_KNX].connected
-
-    @property
-    def should_poll(self):
-        """No polling needed within KNX."""
-        return False
-
     @property
     def brightness(self):
         """Return the brightness of this light between 0..255."""
-        if self.device.supports_brightness:
-            return self.device.current_brightness
+        if self._device.supports_brightness:
+            return self._device.current_brightness
         hsv_color = self._hsv_color
-        if self.device.supports_color and hsv_color:
+        if self._device.supports_color and hsv_color:
             return round(hsv_color[-1] / 100 * 255)
         return None
 
@@ -94,35 +61,35 @@ class KNXLight(LightEntity):
     def hs_color(self):
         """Return the HS color value."""
         rgb = None
-        if self.device.supports_rgbw or self.device.supports_color:
-            rgb, _ = self.device.current_color
+        if self._device.supports_rgbw or self._device.supports_color:
+            rgb, _ = self._device.current_color
         return color_util.color_RGB_to_hs(*rgb) if rgb else None
 
     @property
     def _hsv_color(self):
         """Return the HSV color value."""
         rgb = None
-        if self.device.supports_rgbw or self.device.supports_color:
-            rgb, _ = self.device.current_color
+        if self._device.supports_rgbw or self._device.supports_color:
+            rgb, _ = self._device.current_color
         return color_util.color_RGB_to_hsv(*rgb) if rgb else None
 
     @property
     def white_value(self):
         """Return the white value."""
         white = None
-        if self.device.supports_rgbw:
-            _, white = self.device.current_color
+        if self._device.supports_rgbw:
+            _, white = self._device.current_color
         return white
 
     @property
     def color_temp(self):
         """Return the color temperature in mireds."""
-        if self.device.supports_color_temperature:
-            kelvin = self.device.current_color_temperature
+        if self._device.supports_color_temperature:
+            kelvin = self._device.current_color_temperature
             if kelvin is not None:
                 return color_util.color_temperature_kelvin_to_mired(kelvin)
-        if self.device.supports_tunable_white:
-            relative_ct = self.device.current_tunable_white
+        if self._device.supports_tunable_white:
+            relative_ct = self._device.current_tunable_white
             if relative_ct is not None:
                 # as KNX devices typically use Kelvin we use it as base for
                 # calculating ct from percent
@@ -155,19 +122,22 @@ class KNXLight(LightEntity):
     @property
     def is_on(self):
         """Return true if light is on."""
-        return self.device.state
+        return self._device.state
 
     @property
     def supported_features(self):
         """Flag supported features."""
         flags = 0
-        if self.device.supports_brightness:
+        if self._device.supports_brightness:
             flags |= SUPPORT_BRIGHTNESS
-        if self.device.supports_color:
+        if self._device.supports_color:
             flags |= SUPPORT_COLOR | SUPPORT_BRIGHTNESS
-        if self.device.supports_rgbw:
+        if self._device.supports_rgbw:
             flags |= SUPPORT_COLOR | SUPPORT_WHITE_VALUE
-        if self.device.supports_color_temperature or self.device.supports_tunable_white:
+        if (
+            self._device.supports_color_temperature
+            or self._device.supports_tunable_white
+        ):
             flags |= SUPPORT_COLOR_TEMP
         return flags
 
@@ -191,14 +161,16 @@ class KNXLight(LightEntity):
             or update_white_value
             or update_color_temp
         ):
-            await self.device.set_on()
+            await self._device.set_on()
 
-        if self.device.supports_brightness and (update_brightness and not update_color):
+        if self._device.supports_brightness and (
+            update_brightness and not update_color
+        ):
             # if we don't need to update the color, try updating brightness
             # directly if supported; don't do it if color also has to be
             # changed, as RGB color implicitly sets the brightness as well
-            await self.device.set_brightness(brightness)
-        elif (self.device.supports_rgbw or self.device.supports_color) and (
+            await self._device.set_brightness(brightness)
+        elif (self._device.supports_rgbw or self._device.supports_color) and (
             update_brightness or update_color or update_white_value
         ):
             # change RGB color, white value (if supported), and brightness
@@ -208,25 +180,25 @@ class KNXLight(LightEntity):
                 brightness = DEFAULT_BRIGHTNESS
             if hs_color is None:
                 hs_color = DEFAULT_COLOR
-            if white_value is None and self.device.supports_rgbw:
+            if white_value is None and self._device.supports_rgbw:
                 white_value = DEFAULT_WHITE_VALUE
             rgb = color_util.color_hsv_to_RGB(*hs_color, brightness * 100 / 255)
-            await self.device.set_color(rgb, white_value)
+            await self._device.set_color(rgb, white_value)
 
         if update_color_temp:
             kelvin = int(color_util.color_temperature_mired_to_kelvin(mireds))
             kelvin = min(self._max_kelvin, max(self._min_kelvin, kelvin))
 
-            if self.device.supports_color_temperature:
-                await self.device.set_color_temperature(kelvin)
-            elif self.device.supports_tunable_white:
+            if self._device.supports_color_temperature:
+                await self._device.set_color_temperature(kelvin)
+            elif self._device.supports_tunable_white:
                 relative_ct = int(
                     255
                     * (kelvin - self._min_kelvin)
                     / (self._max_kelvin - self._min_kelvin)
                 )
-                await self.device.set_tunable_white(relative_ct)
+                await self._device.set_tunable_white(relative_ct)
 
     async def async_turn_off(self, **kwargs):
         """Turn the light off."""
-        await self.device.set_off()
+        await self._device.set_off()
