@@ -1,4 +1,6 @@
 """Support for LCN scenes."""
+from typing import Any
+
 import pypck
 
 from homeassistant.components.scene import Scene
@@ -16,6 +18,8 @@ from .const import (
 )
 from .helpers import get_connection
 
+PARALLEL_UPDATES = 0
+
 
 async def async_setup_platform(
     hass, hass_config, async_add_entities, discovery_info=None
@@ -63,9 +67,9 @@ class LcnScene(LcnDevice, Scene):
     async def async_added_to_hass(self):
         """Run when entity about to be added to hass."""
 
-    async def async_activate(self):
+    async def async_activate(self, **kwargs: Any) -> None:
         """Activate scene."""
-        self.address_connection.activate_scene(
+        await self.address_connection.activate_scene(
             self.register_id,
             self.scene_id,
             self.output_ports,
