@@ -1,5 +1,22 @@
 """Meteo-France component constants."""
 
+from homeassistant.components.weather import (
+    ATTR_CONDITION_CLEAR_NIGHT,
+    ATTR_CONDITION_CLOUDY,
+    ATTR_CONDITION_EXCEPTIONAL,
+    ATTR_CONDITION_FOG,
+    ATTR_CONDITION_HAIL,
+    ATTR_CONDITION_LIGHTNING,
+    ATTR_CONDITION_LIGHTNING_RAINY,
+    ATTR_CONDITION_PARTLYCLOUDY,
+    ATTR_CONDITION_POURING,
+    ATTR_CONDITION_RAINY,
+    ATTR_CONDITION_SNOWY,
+    ATTR_CONDITION_SNOWY_RAINY,
+    ATTR_CONDITION_SUNNY,
+    ATTR_CONDITION_WINDY,
+    ATTR_CONDITION_WINDY_VARIANT,
+)
 from homeassistant.const import (
     DEVICE_CLASS_PRESSURE,
     DEVICE_CLASS_TEMPERATURE,
@@ -126,26 +143,31 @@ SENSOR_TYPES = {
 }
 
 CONDITION_CLASSES = {
-    "clear-night": ["Nuit Claire", "Nuit claire"],
-    "cloudy": ["Très nuageux", "Couvert"],
-    "fog": [
+    ATTR_CONDITION_CLEAR_NIGHT: ["Nuit Claire", "Nuit claire"],
+    ATTR_CONDITION_CLOUDY: ["Très nuageux", "Couvert"],
+    ATTR_CONDITION_FOG: [
         "Brume ou bancs de brouillard",
         "Brume",
         "Brouillard",
         "Brouillard givrant",
+        "Bancs de Brouillard",
     ],
-    "hail": ["Risque de grêle", "Risque de grèle"],
-    "lightning": ["Risque d'orages", "Orages"],
-    "lightning-rainy": ["Pluie orageuses", "Pluies orageuses", "Averses orageuses"],
-    "partlycloudy": [
+    ATTR_CONDITION_HAIL: ["Risque de grêle", "Risque de grèle"],
+    ATTR_CONDITION_LIGHTNING: ["Risque d'orages", "Orages"],
+    ATTR_CONDITION_LIGHTNING_RAINY: [
+        "Pluie orageuses",
+        "Pluies orageuses",
+        "Averses orageuses",
+    ],
+    ATTR_CONDITION_PARTLYCLOUDY: [
         "Ciel voilé",
         "Ciel voilé nuit",
         "Éclaircies",
         "Eclaircies",
         "Peu nuageux",
     ],
-    "pouring": ["Pluie forte"],
-    "rainy": [
+    ATTR_CONDITION_POURING: ["Pluie forte"],
+    ATTR_CONDITION_RAINY: [
         "Bruine / Pluie faible",
         "Bruine",
         "Pluie faible",
@@ -157,16 +179,16 @@ CONDITION_CLASSES = {
         "Averses",
         "Pluie",
     ],
-    "snowy": [
+    ATTR_CONDITION_SNOWY: [
         "Neige / Averses de neige",
         "Neige",
         "Averses de neige",
         "Neige forte",
         "Quelques flocons",
     ],
-    "snowy-rainy": ["Pluie et neige", "Pluie verglaçante"],
-    "sunny": ["Ensoleillé"],
-    "windy": [],
-    "windy-variant": [],
-    "exceptional": [],
+    ATTR_CONDITION_SNOWY_RAINY: ["Pluie et neige", "Pluie verglaçante"],
+    ATTR_CONDITION_SUNNY: ["Ensoleillé"],
+    ATTR_CONDITION_WINDY: [],
+    ATTR_CONDITION_WINDY_VARIANT: [],
+    ATTR_CONDITION_EXCEPTIONAL: [],
 }
