@@ -1,7 +1,7 @@
 """Integrates Native Apps to Home Assistant."""
 import asyncio
 
-from homeassistant.components import cloud
+from homeassistant.components import cloud, notify as hass_notify
 from homeassistant.components.webhook import (
     async_register as webhook_register,
     async_unregister as webhook_unregister,
@@ -93,7 +93,7 @@ async def async_setup_entry(hass, entry):
 
     hass.data[DOMAIN][DATA_DEVICES][webhook_id] = device
 
-    registration_name = "Mobile App: {}".format(registration[ATTR_DEVICE_NAME])
+    registration_name = f"Mobile App: {registration[ATTR_DEVICE_NAME]}"
     webhook_register(hass, DOMAIN, registration_name, webhook_id, handle_webhook)
 
     for domain in PLATFORMS:
@@ -101,6 +101,8 @@ async def async_setup_entry(hass, entry):
             hass.config_entries.async_forward_entry_setup(entry, domain)
         )
 
+    await hass_notify.async_reload(hass, DOMAIN)
+
     return True
 
 
@@ -117,7 +119,12 @@ async def async_unload_entry(hass, entry):
     if not unload_ok:
         return False
 
-    webhook_unregister(hass, entry.data[CONF_WEBHOOK_ID])
+    webhook_id = entry.data[CONF_WEBHOOK_ID]
+
+    webhook_unregister(hass, webhook_id)
+    del hass.data[DOMAIN][DATA_CONFIG_ENTRIES][webhook_id]
+    del hass.data[DOMAIN][DATA_DEVICES][webhook_id]
+    await hass_notify.async_reload(hass, DOMAIN)
 
     return True
 
