@@ -1,14 +1,10 @@
 """Support for Netgear LTE binary sensors."""
-import logging
-
 from homeassistant.components.binary_sensor import DOMAIN, BinarySensorEntity
 from homeassistant.exceptions import PlatformNotReady
 
 from . import CONF_MONITORED_CONDITIONS, DATA_KEY, LTEEntity
 from .sensor_types import BINARY_SENSOR_CLASSES
 
-_LOGGER = logging.getLogger(__name__)
-
 
 async def async_setup_platform(hass, config, async_add_entities, discovery_info):
     """Set up Netgear LTE binary sensor devices."""
