@@ -1,5 +1,4 @@
 """Support for Notion sensors."""
-import logging
 from typing import Callable
 
 from homeassistant.config_entries import ConfigEntry
@@ -8,9 +7,7 @@ from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
 
 from . import NotionEntity
-from .const import DATA_COORDINATOR, DOMAIN, SENSOR_TEMPERATURE
-
-_LOGGER = logging.getLogger(__name__)
+from .const import DATA_COORDINATOR, DOMAIN, LOGGER, SENSOR_TEMPERATURE
 
 SENSOR_TYPES = {SENSOR_TEMPERATURE: ("Temperature", "temperature", TEMP_CELSIUS)}
 
@@ -79,12 +76,12 @@ class NotionSensor(NotionEntity):
     @callback
     def _async_update_from_latest_data(self) -> None:
         """Fetch new state data for the sensor."""
-        task = self.coordinator.data["tasks"][self._task_id]
+        task = self.coordinator.data["tasks"][self.task_id]
 
         if task["task_type"] == SENSOR_TEMPERATURE:
             self._state = round(float(task["status"]["value"]), 1)
         else:
-            _LOGGER.error(
+            LOGGER.error(
                 "Unknown task type: %s: %s",
                 self.coordinator.data["sensors"][self._sensor_id],
                 task["task_type"],
