@@ -1,6 +1,4 @@
 """Support for Rflink sensors."""
-import logging
-
 from rflink.parser import PACKET_FIELDS, UNITS
 import voluptuous as vol
 
@@ -28,8 +26,6 @@ from . import (
     RflinkDevice,
 )
 
-_LOGGER = logging.getLogger(__name__)
-
 SENSOR_ICONS = {
     "humidity": "mdi:water-percent",
     "battery": "mdi:battery",
