@@ -1,14 +1,13 @@
 """Support for binary sensor using RPi GPIO."""
-import logging
-
 import voluptuous as vol
 
 from homeassistant.components import rpi_gpio
 from homeassistant.components.binary_sensor import PLATFORM_SCHEMA, BinarySensorEntity
 from homeassistant.const import DEVICE_DEFAULT_NAME
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.reload import setup_reload_service
 
-_LOGGER = logging.getLogger(__name__)
+from . import DOMAIN, PLATFORMS
 
 CONF_BOUNCETIME = "bouncetime"
 CONF_INVERT_LOGIC = "invert_logic"
@@ -33,6 +32,9 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Raspberry PI GPIO devices."""
+
+    setup_reload_service(hass, DOMAIN, PLATFORMS)
+
     pull_mode = config.get(CONF_PULL_MODE)
     bouncetime = config.get(CONF_BOUNCETIME)
     invert_logic = config.get(CONF_INVERT_LOGIC)
