@@ -1,6 +1,5 @@
 """Sensor support for Skybell Doorbells."""
 from datetime import timedelta
-import logging
 
 import voluptuous as vol
 
@@ -10,8 +9,6 @@ import homeassistant.helpers.config_validation as cv
 
 from . import DEFAULT_ENTITY_NAMESPACE, DOMAIN as SKYBELL_DOMAIN, SkybellDevice
 
-_LOGGER = logging.getLogger(__name__)
-
 SCAN_INTERVAL = timedelta(seconds=30)
 
 # Sensor types: Name, icon
