@@ -1,13 +1,8 @@
 """Base class for August entity."""
-
-import logging
-
 from homeassistant.helpers.entity import Entity
 
 from .const import DEFAULT_NAME, DOMAIN
 
-_LOGGER = logging.getLogger(__name__)
-
 
 class TadoZoneEntity(Entity):
     """Base implementation for tado device."""
