@@ -1,6 +1,5 @@
 """Commands part of Websocket API."""
 import asyncio
-import logging
 
 import voluptuous as vol
 
@@ -22,8 +21,6 @@ from homeassistant.loader import IntegrationNotFound, async_get_integration
 
 from . import const, decorators, messages
 
-_LOGGER = logging.getLogger(__name__)
-
 # mypy: allow-untyped-calls, allow-untyped-defs
 
 
