@@ -1,7 +1,7 @@
 """Zerproc light platform."""
 from datetime import timedelta
 import logging
-from typing import Callable, List
+from typing import Callable, List, Optional
 
 import pyzerproc
 
@@ -142,6 +142,11 @@ class ZerprocLight(LightEntity):
             "manufacturer": "Zerproc",
         }
 
+    @property
+    def icon(self) -> Optional[str]:
+        """Return the icon to use in the frontend."""
+        return "mdi:string-lights"
+
     @property
     def supported_features(self):
         """Flag supported features."""
